Python Module Index — gensim documentation

### Navigation

- index
- modules |
- Gensim home|
- API reference|
- Tutorials »

# Python Module Index

g

| g |
| `gensim` |
| `gensim.corpora` | Package for corpora I/O
| `gensim.corpora.bleicorpus` | Corpus in Blei's LDA-C format
| `gensim.corpora.dictionary` | Construct word<->id mappings
| `gensim.corpora.dmlcorpus` | Corpus in DML-CZ format
| `gensim.corpora.lowcorpus` | Corpus in List-of-Words format
| `gensim.corpora.mmcorpus` | Corpus in Matrix Market format
| `gensim.corpora.svmlightcorpus` | Corpus in SVMlight format
| `gensim.corpora.wikicorpus` | Corpus from a Wikipedia dump
| `gensim.interfaces` | Core gensim interfaces
| `gensim.matutils` | Math utils
| `gensim.models` | Package for transformation models
| `gensim.models.lda_dispatcher` | Dispatcher for distributed LDA
| `gensim.models.lda_worker` | Worker for distributed LDA
| `gensim.models.ldamodel` | Latent Dirichlet Allocation
| `gensim.models.lsi_dispatcher` | Dispatcher for distributed LSI
| `gensim.models.lsi_worker` | Worker for distributed LSI
| `gensim.models.lsimodel` | Latent Semantic Indexing
| `gensim.models.rpmodel` | Random Projections
| `gensim.models.tfidfmodel` | TF-IDF model
| `gensim.similarities.docsim` | Document similarity queries
| `gensim.utils` | Various utility functions

### Navigation

- index
- modules |
- Gensim home|
- API reference|
- Tutorials »